pitchtools.list_named_chromatic_pitches_in_expr
===============================================

.. autofunction:: abjad.tools.pitchtools.list_named_chromatic_pitches_in_expr.list_named_chromatic_pitches_in_expr
